# No CLI commands found in console_scripts in settings.ini file.

 For documenting CLI commands, please add command line executables in `console_scripts` in `settings.ini` file. 
 
If you do not want this page to be rendered as part of the documentation, please remove the following lines from the **mkdocs/summary_template.txt** file and build the docs again.

```
- CLI
{cli}
```

